/*********************************************************************************
**
**   $Id: WorkOrderForm.cpp,v 1.8 2004/05/24 11:59:49 croftj Exp $
**   Copyright (c) 2004 Joe Croft <joe@croftj.net>
**   
**   This file is part of ah2.
**
**   ah2 is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
**   Foobar is distributed in the hope that it will be useful,
**   but WITHOUT ANY WARRANTY; without even the implied warranty of
**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**   GNU General Public License for more details.
**
**   You should have received a copy of the GNU General Public License
**   along with Foobar; if not, write to the Free Software
**   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
*********************************************************************************/

#include <qlistbox.h>
#include <qmessagebox.h>
#include <qregexp.h>
#include <qsqlquery.h>
#include "WorkOrderForm.h"

extern QSqlDatabase *autohouse;

QString DateEntry::get() const
{
   QString rv;
   printf("DateEntry::get(): Enter\n");
   rv = date().toString(Qt::ISODate);
   printf("DateEntry::get(): Exit |%s|\n", (const char*)rv);
   return(rv);
}

void DateEntry::set(QString t)
{
   printf("DateEntry::set(): Entry  |%s|\n", (const char*)t);
   QRegExp reDate("([0-9][0-9][0-9][0-9])-([0-9][0-9])-([0-9][0-9])");
   int pos;
   if ((pos = reDate.search(t)) >= 0)
   {
      QString year = reDate.cap(1);
      QString mon = reDate.cap(2);
      QString day = reDate.cap(3);
      printf("DateEntry::set(): %s/%s/%s\n", (const char*)mon, (const char*)day, (const char*)year);
      QDate d(year.toInt(), mon.toInt(), day.toInt());
      setDate(d);
   }
   printf("DateEntry::set(): Exit pos = %d\n", pos);
}

WorkOrderForm::WorkOrderForm(QWidget *pParent, const char *pName, WFlags f) :
           DataForm(autohouse, "workorders", 7, 3, pParent, pName, f)
{
   printf("WorkOrderForm::WorkOrderForm(): Enter()\n");
   fflush(stdout);

   wonumEdit         = new QLineEdit(this);
   dateinEdit        = new DateEntry(this);
   dateoutEdit       = new DateEntry(this);
   recomendEdit      = new QTextEdit(this);
   hazmatEdit        = new MoneyEdit(this);
   r_laborEdit       = new MoneyEdit(this);
   closedEdit        = new QLineEdit(this);
   closedEdit->setReadOnly(true);
   taxEdit           = new MoneyEdit(this);
   taxEdit->setReadOnly(true);
   totalEdit         = new MoneyEdit(this);
   totalEdit->setReadOnly(true);

   wonumEdit->setReadOnly(true);

   DataFields fields[] =
   {
      { "ident",        "Invoice",        0,  0,  0,  0,  0, 10,  0, "",   wonumEdit, NULL },
      { "closed",       "Closed",         0,  1,  0,  0,  0,  2,  0, "",   closedEdit, NULL },
      { "date_in",      "Date In",        1,  0,  0,  0, 10, 10,  0, "",   dateinEdit, "date" },
      { "od_in",        "Odom. In",       1,  1,  0,  0, 10, 10,  0, "",   NULL, NULL },
      { "date_out",     "Date Out",       2,  0,  0,  0, 10, 10,  0, "",   dateoutEdit, "date" },
      { "od_out",       "Odom. Out",      2,  1,  0,  0, 10, 10,  0, "",   NULL, NULL },
      { "r_labor",      "Labor Rate",     3,  0,  0,  0, 10, 10,  0, "",   r_laborEdit, "money" },
      { "hazmat",       "Haz. Mat.",      3,  1,  0,  0, 10, 10,  0, "",   hazmatEdit, "money" },
      { "tax",          "Sales Tax",      4,  0,  0,  0, 10, 10,  0, "",   taxEdit, "money" },
      { "r_tax",        "Tax Rate",       4,  1,  0,  0,  0, 10,  0, "",   NULL, NULL },
      { "total",        "Total",          5,  1,  0,  0,  0, 10,  1, "",   totalEdit, "money" },
      { "recomend",     "Recomended",     0,  2,  0,  6,  0,  0,  0, "",   recomendEdit, NULL },
      {  NULL, NULL, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL }
   };
   printf("WorkOrderForm::WorkOrderForm(): Setting Fields()\n");
   fflush(stdout);
   setFields(fields);
   printf("WorkOrderForm::WorkOrderForm(): Exit()\n");
   fflush(stdout);
}

void WorkOrderForm::deleteRecord() 
{
   QString s;
   printf("WorkOrderForm::deleteRecord(): Enter()\n");
   fflush(stdout);
   s = "Deletng Workorder '" +
        wonumEdit->text() +
        "'. Are you sure?"; 
   printf("WorkOrderForm::deleteRecord(): Opening Message Box\n");
   fflush(stdout);
   if (QMessageBox::warning(NULL, "Deleting Work Order", s, QMessageBox::Yes, 
                           QMessageBox::No | QMessageBox::Escape | QMessageBox::Default) == QMessageBox::Yes) 
   {
      if ( closedEdit->text() != "N" ) 
      {
         s = "This work order as already been closed. Closing this work order may affect your accounting.\nAre you absolutely sure you want to delete it?";
         if (QMessageBox::critical(NULL, "Deleting Closed Work Order", s, QMessageBox::Yes, 
                                 QMessageBox::No | QMessageBox::Escape | QMessageBox::Default) == QMessageBox::No) 
         {
            printf("WorkOrderForm::deleteRecord(): Exit()\n");
            fflush(stdout);
            return;
         }
      }
      printf("WorkOrderForm::deleteRecord(): deleting record()\n");
      fflush(stdout);
      DataForm::deleteRecord();
      emit updated();
   }
   printf("WorkOrderForm::deleteRecord(): Exit()\n");
   fflush(stdout);
}
